@@ -106,17 +106,6 @@ union_new_resolve(JSContext *context,
 
             method_name = g_base_info_get_name( (GIBaseInfo*) method_info);
 
-            /* we do not define deprecated methods in the prototype */
-            if (g_base_info_is_deprecated( (GIBaseInfo*) method_info)) {
-                gjs_debug(GJS_DEBUG_GBOXED,
-                          "Ignoring definition of deprecated method %s in prototype %s.%s",
-                          method_name,
-                          g_base_info_get_namespace( (GIBaseInfo*) priv->info),
-                          g_base_info_get_name( (GIBaseInfo*) priv->info));
-                g_base_info_unref( (GIBaseInfo*) method_info);
-                goto out;
-            }
-
             gjs_debug(GJS_DEBUG_GBOXED,
                       "Defining method %s in prototype for %s.%s",
                       method_name,
