@@ -78,3 +78,55 @@ function removeNullProperties(obj) {
             removeNullProperties(obj[property]);
     }
 }
+
+/**
+ * Binds obj to callback. Makes it possible to refer to "obj"
+ * using this within the callback.
+ * @param {object} obj the object to bind
+ * @param {function} callback callback to bind obj in
+ * @param arguments additional arguments to the callback
+ * @returns: a new callback
+ * @type: function
+ */
+function bind(obj, callback) {
+    if (typeof(obj) != 'object') {
+        throw new Error(
+            "first argument to Lang.bind() must be an object, not " +
+                typeof(obj));
+    }
+
+    if (typeof(callback) != 'function') {
+        throw new Error(
+            "second argument to Lang.bind() must be a function, not " +
+                typeof(callback));
+    }
+
+    if (callback.bind && arguments.length == 2) // ECMAScript 5 (but only if not passing any bindArguments)
+	return callback.bind(obj);
+
+    let me = obj;
+    let bindArguments = Array.prototype.slice.call(arguments, 2);
+
+    return function() {
+        let args = Array.prototype.slice.call(arguments);
+        args = args.concat(bindArguments);
+        return callback.apply(me, args);
+    };
+}
+
+function defineAccessorProperty(object, name, getter, setter) {
+    if (Object.defineProperty) { // ECMAScript 5
+	Object.defineProperty(object, name, { get: getter,
+					      set: setter,
+					      configurable: true,
+					      enumerable: true });
+	return;
+    }
+
+    // fallback to deprecated way
+    object.__defineGetter__(name, getter);
+    object.__defineSetter__(name, setter);
+}
+
+// Merge stuff defined in native code
+copyProperties(imports.langNative, this);
