@@ -7,6 +7,7 @@ if (!('assertEquals' in this)) { /* allow running this test standalone */
 }
 
 // We use Gio to have some objects that we know exist
+const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
 const Lang = imports.lang;
 
@@ -280,20 +281,26 @@ function testGSListIn() {
 
 /* Array tests */
 function testArrayIn() {
-    assertEquals(10, Everything.test_array_int_in(4, [1,2,3,4]));
-    assertEquals(10, Everything.test_array_gint8_in(4, [1,2,3,4]));
-    assertEquals(10, Everything.test_array_gint16_in(4, [1,2,3,4]));
-    assertEquals(10, Everything.test_array_gint32_in(4, [1,2,3,4]));
+    assertEquals(10, Everything.test_array_int_in([1,2,3,4]));
+    assertEquals(10, Everything.test_array_gint8_in([1,2,3,4]));
+    assertEquals(10, Everything.test_array_gint16_in([1,2,3,4]));
+    assertEquals(10, Everything.test_array_gint32_in([1,2,3,4]));
     // FIXME: arrays of int64 are unimplemented
-    //assertEquals(10, Everything.test_array_gint64_in(4, [1,2,3,4]));
+    //assertEquals(10, Everything.test_array_gint64_in([1,2,3,4]));
 
     // implicit conversions from strings to int arrays
-    assertEquals(10, Everything.test_array_gint8_in(4, "\x01\x02\x03\x04"));
-    assertEquals(10, Everything.test_array_gint16_in(4, "\x01\x02\x03\x04"));
-    assertEquals(2560, Everything.test_array_gint16_in(4, "\u0100\u0200\u0300\u0400"));
+    assertEquals(10, Everything.test_array_gint8_in("\x01\x02\x03\x04"));
+    assertEquals(10, Everything.test_array_gint16_in("\x01\x02\x03\x04"));
+    assertEquals(2560, Everything.test_array_gint16_in("\u0100\u0200\u0300\u0400"));
 }
 
 function testArrayOut() {
+    function arrayEqual(ref, res) {
+	assertEquals(ref.length, res.length);
+	for (let i = 0; i < ref.length; i++)
+	    assertEquals(ref[i], res[i]);
+    }
+
     let array =  Everything.test_array_fixed_size_int_out();
     assertEquals(0, array[0]);
     assertEquals(4, array[4]);
@@ -301,7 +308,16 @@ function testArrayOut() {
     assertEquals(0, array[0]);
     assertEquals(4, array[4]);
 
-    // FIXME: test_array_int_full_out and test_array_int_none_out unimplemented
+    array = Everything.test_array_int_none_out();
+    arrayEqual([1, 2, 3, 4, 5], array);
+
+    array = Everything.test_array_int_full_out();
+    arrayEqual([0, 1, 2, 3, 4], array);
+
+    array = Everything.test_array_int_null_out();
+    assertEquals(0, array.length);
+
+    Everything.test_array_int_null_in(null);
 }
 
 /* GHash type */
@@ -462,4 +478,25 @@ function testStrvInGValue() {
     assertEquals(v[2], "three");
 }
 
+function testVariant() {
+    // Cannot access the variant contents, for now
+    let ivar = Everything.test_gvariant_i();
+    assertEquals('i', ivar.get_type_string());
+    assertTrue(ivar.equal(GLib.Variant.new_int32(1)));
+
+    let svar = Everything.test_gvariant_s();
+    assertEquals('s', String.fromCharCode(svar.classify()));
+    assertEquals('one', svar.get_string()[0]);
+
+    let asvvar = Everything.test_gvariant_asv();
+    assertEquals(2, asvvar.n_children());
+
+    let asvar = Everything.test_gvariant_as();
+    let as = asvar.get_strv();
+    assertEquals('one', as[0]);
+    assertEquals('two', as[1]);
+    assertEquals('three', as[2]);
+    assertEquals(3, as.length);
+}
+
 gjstestRun();
